Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation.



1369
1370
1371
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#framesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2ExplicitContentFrame>

All video frames where explicit content was detected. Corresponds to the JSON property frames



1362
1363
1364
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1362

def frames
  @frames
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


1367
1368
1369
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1367

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1374
1375
1376
1377
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1374

def update!(**args)
  @frames = args[:frames] if args.key?(:frames)
  @version = args[:version] if args.key?(:version)
end