Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1beta2LabelAnnotation.



1577
1578
1579
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



1555
1556
1557
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1555

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2Entity

Detected entity from video analysis. Corresponds to the JSON property entity



1560
1561
1562
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1560

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



1565
1566
1567
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1565

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



1570
1571
1572
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1570

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


1575
1576
1577
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1575

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1582
1583
1584
1585
1586
1587
1588
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1582

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end