Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb
Overview
Annotation corresponding to one detected, tracked and recognized logo class.
Instance Attribute Summary collapse
-
#entity ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2Entity
Detected entity from video analysis.
-
#segments ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2VideoSegment>
All video segments where the recognized logo appears.
-
#tracks ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2Track>
All logo tracks where the recognized logo appears.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation
constructor
A new instance of GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation
Returns a new instance of GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation.
1663 1664 1665 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2Entity
Detected entity from video analysis.
Corresponds to the JSON property entity
1649 1650 1651 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1649 def entity @entity end |
#segments ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2VideoSegment>
All video segments where the recognized logo appears. There might be multiple
instances of the same logo class appearing in one VideoSegment.
Corresponds to the JSON property segments
1655 1656 1657 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1655 def segments @segments end |
#tracks ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2Track>
All logo tracks where the recognized logo appears. Each track corresponds to
one logo instance appearing in consecutive frames.
Corresponds to the JSON property tracks
1661 1662 1663 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1661 def tracks @tracks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1668 1669 1670 1671 1672 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1668 def update!(**args) @entity = args[:entity] if args.key?(:entity) @segments = args[:segments] if args.key?(:segments) @tracks = args[:tracks] if args.key?(:tracks) end |