Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb
Overview
Alternative hypotheses (a.k.a. n-best list).
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Output only.
-
#transcript ⇒ String
Transcript text representing the words that the user spoke.
-
#words ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2WordInfo>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative
constructor
A new instance of GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative
Returns a new instance of GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative.
1898 1899 1900 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Output only. The confidence estimate between 0.0 and 1.0. A higher number
indicates an estimated greater likelihood that the recognized words are
correct. This field is set only for the top alternative. This field is not
guaranteed to be accurate and users should not rely on it to be always
provided. The default of 0.0 is a sentinel value indicating confidence was
not set.
Corresponds to the JSON property confidence
1884 1885 1886 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1884 def confidence @confidence end |
#transcript ⇒ String
Transcript text representing the words that the user spoke.
Corresponds to the JSON property transcript
1889 1890 1891 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1889 def transcript @transcript end |
#words ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2WordInfo>
Output only. A list of word-specific information for each recognized word.
Note: When enable_speaker_diarization is set to true, you will see all the
words from the beginning of the audio.
Corresponds to the JSON property words
1896 1897 1898 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1896 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1903 1904 1905 1906 1907 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 1903 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @transcript = args[:transcript] if args.key?(:transcript) @words = args[:words] if args.key?(:words) end |