Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Annotation progress for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress

Returns a new instance of GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress.



2156
2157
2158
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_statusGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus

Status of exporting annotation response to user specified output_uri. Corresponds to the JSON property exportStatus



2122
2123
2124
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2122

def export_status
  @export_status
end

#featureString

Specifies which feature is being tracked if the request contains more than one feature. Corresponds to the JSON property feature

Returns:

  • (String)


2128
2129
2130
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2128

def feature
  @feature
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


2133
2134
2135
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2133

def input_uri
  @input_uri
end

#progress_percentFixnum

Approximate percentage processed thus far. Guaranteed to be 100 when fully processed. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


2139
2140
2141
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2139

def progress_percent
  @progress_percent
end

#segmentGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1beta2VideoSegment

Video segment. Corresponds to the JSON property segment



2144
2145
2146
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2144

def segment
  @segment
end

#start_timeString

Time when the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


2149
2150
2151
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2149

def start_time
  @start_time
end

#update_timeString

Time of the most recent update. Corresponds to the JSON property updateTime

Returns:

  • (String)


2154
2155
2156
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2154

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2161
2162
2163
2164
2165
2166
2167
2168
2169
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2161

def update!(**args)
  @export_status = args[:export_status] if args.key?(:export_status)
  @feature = args[:feature] if args.key?(:feature)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @segment = args[:segment] if args.key?(:segment)
  @start_time = args[:start_time] if args.key?(:start_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end