Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1DetectedLandmark
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1DetectedLandmark
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb
Overview
A generic detected landmark represented by name in string format and a 2D location.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
The confidence score of the detected landmark.
-
#name ⇒ String
The name of this landmark, for example, left_hand, right_shoulder.
-
#point ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1NormalizedVertex
A vertex represents a 2D point in the image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1DetectedLandmark
constructor
A new instance of GoogleCloudVideointelligenceV1p1beta1DetectedLandmark.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1DetectedLandmark
Returns a new instance of GoogleCloudVideointelligenceV1p1beta1DetectedLandmark.
2497 2498 2499 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
The confidence score of the detected landmark. Range [0, 1].
Corresponds to the JSON property confidence
2484 2485 2486 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2484 def confidence @confidence end |
#name ⇒ String
The name of this landmark, for example, left_hand, right_shoulder.
Corresponds to the JSON property name
2489 2490 2491 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2489 def name @name end |
#point ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1NormalizedVertex
A vertex represents a 2D point in the image. NOTE: the normalized vertex
coordinates are relative to the original image and range from 0 to 1.
Corresponds to the JSON property point
2495 2496 2497 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2495 def point @point end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2502 2503 2504 2505 2506 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2502 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @name = args[:name] if args.key?(:name) @point = args[:point] if args.key?(:point) end |