Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1ExplicitContentAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1ExplicitContentAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1ExplicitContentAnnotation.



2557
2558
2559
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#framesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame>

All video frames where explicit content was detected. Corresponds to the JSON property frames



2550
2551
2552
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2550

def frames
  @frames
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


2555
2556
2557
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2555

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2562
2563
2564
2565
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2562

def update!(**args)
  @frames = args[:frames] if args.key?(:frames)
  @version = args[:version] if args.key?(:version)
end