Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1LabelAnnotation.



2765
2766
2767
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



2743
2744
2745
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2743

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



2748
2749
2750
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2748

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



2753
2754
2755
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2753

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



2758
2759
2760
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2758

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


2763
2764
2765
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2763

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2770
2771
2772
2773
2774
2775
2776
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2770

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end