Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb
Overview
Annotation corresponding to one detected, tracked and recognized logo class.
Instance Attribute Summary collapse
-
#entity ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1Entity
Detected entity from video analysis.
-
#segments ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1VideoSegment>
All video segments where the recognized logo appears.
-
#tracks ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1Track>
All logo tracks where the recognized logo appears.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation
constructor
A new instance of GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation
Returns a new instance of GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation.
2851 2852 2853 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1Entity
Detected entity from video analysis.
Corresponds to the JSON property entity
2837 2838 2839 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2837 def entity @entity end |
#segments ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1VideoSegment>
All video segments where the recognized logo appears. There might be multiple
instances of the same logo class appearing in one VideoSegment.
Corresponds to the JSON property segments
2843 2844 2845 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2843 def segments @segments end |
#tracks ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1Track>
All logo tracks where the recognized logo appears. Each track corresponds to
one logo instance appearing in consecutive frames.
Corresponds to the JSON property tracks
2849 2850 2851 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2849 def tracks @tracks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2856 2857 2858 2859 2860 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 2856 def update!(**args) @entity = args[:entity] if args.key?(:entity) @segments = args[:segments] if args.key?(:segments) @tracks = args[:tracks] if args.key?(:tracks) end |