Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Annotation progress for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress.



3344
3345
3346
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_statusGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus

Status of exporting annotation response to user specified output_uri. Corresponds to the JSON property exportStatus



3310
3311
3312
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3310

def export_status
  @export_status
end

#featureString

Specifies which feature is being tracked if the request contains more than one feature. Corresponds to the JSON property feature

Returns:

  • (String)


3316
3317
3318
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3316

def feature
  @feature
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


3321
3322
3323
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3321

def input_uri
  @input_uri
end

#progress_percentFixnum

Approximate percentage processed thus far. Guaranteed to be 100 when fully processed. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


3327
3328
3329
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3327

def progress_percent
  @progress_percent
end

#segmentGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p1beta1VideoSegment

Video segment. Corresponds to the JSON property segment



3332
3333
3334
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3332

def segment
  @segment
end

#start_timeString

Time when the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


3337
3338
3339
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3337

def start_time
  @start_time
end

#update_timeString

Time of the most recent update. Corresponds to the JSON property updateTime

Returns:

  • (String)


3342
3343
3344
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3342

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3349
3350
3351
3352
3353
3354
3355
3356
3357
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3349

def update!(**args)
  @export_status = args[:export_status] if args.key?(:export_status)
  @feature = args[:feature] if args.key?(:feature)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @segment = args[:segment] if args.key?(:segment)
  @start_time = args[:start_time] if args.key?(:start_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end