Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1LabelAnnotation.



3953
3954
3955
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



3931
3932
3933
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3931

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



3936
3937
3938
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3936

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



3941
3942
3943
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3941

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



3946
3947
3948
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3946

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


3951
3952
3953
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3951

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3958
3959
3960
3961
3962
3963
3964
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 3958

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end