Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1TimestampedObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

For tracking related features. An object at time_offset with attributes, and located with normalized_bounding_box.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1TimestampedObject

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1TimestampedObject.



4441
4442
4443
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1DetectedAttribute>

Optional. The attributes of the object in the bounding box. Corresponds to the JSON property attributes



4422
4423
4424
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4422

def attributes
  @attributes
end

#landmarksArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1DetectedLandmark>

Optional. The detected landmarks. Corresponds to the JSON property landmarks



4427
4428
4429
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4427

def landmarks
  @landmarks
end

#normalized_bounding_boxGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1NormalizedBoundingBox

Normalized bounding box. The normalized vertex coordinates are relative to the original image. Range: [0, 1]. Corresponds to the JSON property normalizedBoundingBox



4433
4434
4435
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4433

def normalized_bounding_box
  @normalized_bounding_box
end

#time_offsetString

Time-offset, relative to the beginning of the video, corresponding to the video frame for this object. Corresponds to the JSON property timeOffset

Returns:

  • (String)


4439
4440
4441
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4439

def time_offset
  @time_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4446
4447
4448
4449
4450
4451
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4446

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @landmarks = args[:landmarks] if args.key?(:landmarks)
  @normalized_bounding_box = args[:normalized_bounding_box] if args.key?(:normalized_bounding_box)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
end