Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Annotation progress for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress.



4532
4533
4534
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_statusGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1ExportToOutputUriStatus

Status of exporting annotation response to user specified output_uri. Corresponds to the JSON property exportStatus



4498
4499
4500
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4498

def export_status
  @export_status
end

#featureString

Specifies which feature is being tracked if the request contains more than one feature. Corresponds to the JSON property feature

Returns:

  • (String)


4504
4505
4506
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4504

def feature
  @feature
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


4509
4510
4511
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4509

def input_uri
  @input_uri
end

#progress_percentFixnum

Approximate percentage processed thus far. Guaranteed to be 100 when fully processed. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


4515
4516
4517
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4515

def progress_percent
  @progress_percent
end

#segmentGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment

Video segment. Corresponds to the JSON property segment



4520
4521
4522
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4520

def segment
  @segment
end

#start_timeString

Time when the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


4525
4526
4527
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4525

def start_time
  @start_time
end

#update_timeString

Time of the most recent update. Corresponds to the JSON property updateTime

Returns:

  • (String)


4530
4531
4532
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4530

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4537
4538
4539
4540
4541
4542
4543
4544
4545
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4537

def update!(**args)
  @export_status = args[:export_status] if args.key?(:export_status)
  @feature = args[:feature] if args.key?(:feature)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @segment = args[:segment] if args.key?(:segment)
  @start_time = args[:start_time] if args.key?(:start_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end