Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1Celebrity
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1Celebrity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb
Overview
Celebrity definition.
Instance Attribute Summary collapse
-
#description ⇒ String
Textual description of additional information about the celebrity, if applicable.
-
#display_name ⇒ String
The celebrity name.
-
#name ⇒ String
The resource name of the celebrity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1Celebrity
constructor
A new instance of GoogleCloudVideointelligenceV1p3beta1Celebrity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1Celebrity
Returns a new instance of GoogleCloudVideointelligenceV1p3beta1Celebrity.
4908 4909 4910 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4908 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Textual description of additional information about the celebrity, if
applicable.
Corresponds to the JSON property description
4894 4895 4896 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4894 def description @description end |
#display_name ⇒ String
The celebrity name.
Corresponds to the JSON property displayName
4899 4900 4901 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4899 def display_name @display_name end |
#name ⇒ String
The resource name of the celebrity. Have the format video-intelligence/kg-mid
indicates a celebrity from preloaded gallery. kg-mid is the id in Google
knowledge graph, which is unique for the celebrity.
Corresponds to the JSON property name
4906 4907 4908 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4906 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4913 4914 4915 4916 4917 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4913 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) end |