Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1DetectedAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

A generic detected attribute represented by name in string format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1DetectedAttribute

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1DetectedAttribute.



4993
4994
4995
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

Detected attribute confidence. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


4979
4980
4981
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4979

def confidence
  @confidence
end

#nameString

The name of the attribute, for example, glasses, dark_glasses, mouth_open. A full list of supported type names will be provided in the document. Corresponds to the JSON property name

Returns:

  • (String)


4985
4986
4987
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4985

def name
  @name
end

#valueString

Text value of the detection result. For example, the value for "HairColor" can be "black", "blonde", etc. Corresponds to the JSON property value

Returns:

  • (String)


4991
4992
4993
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4991

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4998
4999
5000
5001
5002
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4998

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end