Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1DetectedLandmark

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

A generic detected landmark represented by name in string format and a 2D location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1DetectedLandmark

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1DetectedLandmark.



5026
5027
5028
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The confidence score of the detected landmark. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


5013
5014
5015
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5013

def confidence
  @confidence
end

#nameString

The name of this landmark, for example, left_hand, right_shoulder. Corresponds to the JSON property name

Returns:

  • (String)


5018
5019
5020
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5018

def name
  @name
end

#pointGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1NormalizedVertex

A vertex represents a 2D point in the image. NOTE: the normalized vertex coordinates are relative to the original image and range from 0 to 1. Corresponds to the JSON property point



5024
5025
5026
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5024

def point
  @point
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5031
5032
5033
5034
5035
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5031

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @name = args[:name] if args.key?(:name)
  @point = args[:point] if args.key?(:point)
end