Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ExplicitContentAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1ExplicitContentAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1ExplicitContentAnnotation.



5086
5087
5088
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#framesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ExplicitContentFrame>

All video frames where explicit content was detected. Corresponds to the JSON property frames



5079
5080
5081
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5079

def frames
  @frames
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


5084
5085
5086
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5084

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5091
5092
5093
5094
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5091

def update!(**args)
  @frames = args[:frames] if args.key?(:frames)
  @version = args[:version] if args.key?(:version)
end