Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1LabelAnnotation.



5349
5350
5351
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



5327
5328
5329
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5327

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



5332
5333
5334
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5332

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



5337
5338
5339
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5337

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



5342
5343
5344
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5342

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


5347
5348
5349
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5347

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5354
5355
5356
5357
5358
5359
5360
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5354

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end