Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelDetectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelDetectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb
Overview
Config for LABEL_DETECTION.
Instance Attribute Summary collapse
-
#frame_confidence_threshold ⇒ Float
The confidence threshold we perform filtering on the labels from frame-level detection.
-
#label_detection_mode ⇒ String
What labels should be detected with LABEL_DETECTION, in addition to video- level labels or segment-level labels.
-
#model ⇒ String
Model to use for label detection.
-
#stationary_camera ⇒ Boolean
(also: #stationary_camera?)
Whether the video has been shot from a stationary (i.e., non-moving) camera.
-
#video_confidence_threshold ⇒ Float
The confidence threshold we perform filtering on the labels from video-level and shot-level detections.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1LabelDetectionConfig
constructor
A new instance of GoogleCloudVideointelligenceV1p3beta1LabelDetectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1LabelDetectionConfig
Returns a new instance of GoogleCloudVideointelligenceV1p3beta1LabelDetectionConfig.
5405 5406 5407 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frame_confidence_threshold ⇒ Float
The confidence threshold we perform filtering on the labels from frame-level
detection. If not set, it is set to 0.4 by default. The valid range for this
threshold is [0.1, 0.9]. Any value set outside of this range will be clipped.
Note: For best results, follow the default threshold. We will update the
default threshold everytime when we release a new model.
Corresponds to the JSON property frameConfidenceThreshold
5374 5375 5376 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5374 def frame_confidence_threshold @frame_confidence_threshold end |
#label_detection_mode ⇒ String
What labels should be detected with LABEL_DETECTION, in addition to video-
level labels or segment-level labels. If unspecified, defaults to SHOT_MODE.
Corresponds to the JSON property labelDetectionMode
5380 5381 5382 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5380 def label_detection_mode @label_detection_mode end |
#model ⇒ String
Model to use for label detection. Supported values: "builtin/stable" (the
default if unset) and "builtin/latest".
Corresponds to the JSON property model
5386 5387 5388 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5386 def model @model end |
#stationary_camera ⇒ Boolean Also known as: stationary_camera?
Whether the video has been shot from a stationary (i.e., non-moving) camera.
When set to true, might improve detection accuracy for moving objects. Should
be used with SHOT_AND_FRAME_MODE enabled.
Corresponds to the JSON property stationaryCamera
5393 5394 5395 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5393 def stationary_camera @stationary_camera end |
#video_confidence_threshold ⇒ Float
The confidence threshold we perform filtering on the labels from video-level
and shot-level detections. If not set, it's set to 0.3 by default. The valid
range for this threshold is [0.1, 0.9]. Any value set outside of this range
will be clipped. Note: For best results, follow the default threshold. We will
update the default threshold everytime when we release a new model.
Corresponds to the JSON property videoConfidenceThreshold
5403 5404 5405 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5403 def video_confidence_threshold @video_confidence_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5410 5411 5412 5413 5414 5415 5416 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5410 def update!(**args) @frame_confidence_threshold = args[:frame_confidence_threshold] if args.key?(:frame_confidence_threshold) @label_detection_mode = args[:label_detection_mode] if args.key?(:label_detection_mode) @model = args[:model] if args.key?(:model) @stationary_camera = args[:stationary_camera] if args.key?(:stationary_camera) @video_confidence_threshold = args[:video_confidence_threshold] if args.key?(:video_confidence_threshold) end |