Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Annotation corresponding to one detected, tracked and recognized logo class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation.



5491
5492
5493
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entityGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



5477
5478
5479
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5477

def entity
  @entity
end

#segmentsArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoSegment>

All video segments where the recognized logo appears. There might be multiple instances of the same logo class appearing in one VideoSegment. Corresponds to the JSON property segments



5483
5484
5485
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5483

def segments
  @segments
end

#tracksArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1Track>

All logo tracks where the recognized logo appears. Each track corresponds to one logo instance appearing in consecutive frames. Corresponds to the JSON property tracks



5489
5490
5491
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5489

def tracks
  @tracks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5496
5497
5498
5499
5500
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5496

def update!(**args)
  @entity = args[:entity] if args.key?(:entity)
  @segments = args[:segments] if args.key?(:segments)
  @tracks = args[:tracks] if args.key?(:tracks)
end