Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1PersonDetectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Config for PERSON_DETECTION.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1PersonDetectionConfig

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1PersonDetectionConfig.



5745
5746
5747
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_attributesBoolean Also known as: include_attributes?

Whether to enable person attributes detection, such as cloth color (black, blue, etc), type (coat, dress, etc), pattern (plain, floral, etc), hair, etc. Ignored if 'include_bounding_boxes' is set to false. Corresponds to the JSON property includeAttributes

Returns:

  • (Boolean)


5729
5730
5731
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5729

def include_attributes
  @include_attributes
end

#include_bounding_boxesBoolean Also known as: include_bounding_boxes?

Whether bounding boxes are included in the person detection annotation output. Corresponds to the JSON property includeBoundingBoxes

Returns:

  • (Boolean)


5735
5736
5737
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5735

def include_bounding_boxes
  @include_bounding_boxes
end

#include_pose_landmarksBoolean Also known as: include_pose_landmarks?

Whether to enable pose landmarks detection. Ignored if 'include_bounding_boxes' is set to false. Corresponds to the JSON property includePoseLandmarks

Returns:

  • (Boolean)


5742
5743
5744
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5742

def include_pose_landmarks
  @include_pose_landmarks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5750
5751
5752
5753
5754
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5750

def update!(**args)
  @include_attributes = args[:include_attributes] if args.key?(:include_attributes)
  @include_bounding_boxes = args[:include_bounding_boxes] if args.key?(:include_bounding_boxes)
  @include_pose_landmarks = args[:include_pose_landmarks] if args.key?(:include_pose_landmarks)
end