Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1SpeechTranscriptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Config for SPEECH_TRANSCRIPTION.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1SpeechTranscriptionConfig

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1SpeechTranscriptionConfig.



5978
5979
5980
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_output_uri_prefixString

Optional. Legacy field. This field must be a Cloud Storage URI prefix. (e.g., gs://bucket/path/). Corresponds to the JSON property audioOutputUriPrefix

Returns:

  • (String)


5903
5904
5905
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5903

def audio_output_uri_prefix
  @audio_output_uri_prefix
end

#audio_tracksArray<Fixnum>

Optional. For file formats, such as MXF or MKV, supporting multiple audio tracks, specify up to two tracks. Default: track 0. Corresponds to the JSON property audioTracks

Returns:

  • (Array<Fixnum>)


5909
5910
5911
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5909

def audio_tracks
  @audio_tracks
end

#diarization_speaker_countFixnum

Optional. If set, specifies the estimated number of speakers in the conversation. If not set, defaults to '2'. Ignored unless enable_speaker_diarization is set to true. Corresponds to the JSON property diarizationSpeakerCount

Returns:

  • (Fixnum)


5916
5917
5918
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5916

def diarization_speaker_count
  @diarization_speaker_count
end

#enable_automatic_punctuationBoolean Also known as: enable_automatic_punctuation?

Optional. If 'true', adds punctuation to recognition result hypotheses. This feature is only available in select languages. Setting this for requests in other languages has no effect at all. The default 'false' value does not add punctuation to result hypotheses. NOTE: "This is currently offered as an experimental service, complimentary to all users. In the future this may be exclusively available as a premium feature." Corresponds to the JSON property enableAutomaticPunctuation

Returns:

  • (Boolean)


5926
5927
5928
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5926

def enable_automatic_punctuation
  @enable_automatic_punctuation
end

#enable_speaker_diarizationBoolean Also known as: enable_speaker_diarization?

Optional. If 'true', enables speaker detection for each recognized word in the top alternative of the recognition result using a speaker_tag provided in the WordInfo. Note: When this is true, we send all the words from the beginning of the audio for the top alternative in every consecutive response. This is done in order to improve our speaker tags as our models learn to identify the speakers in the conversation over time. Corresponds to the JSON property enableSpeakerDiarization

Returns:

  • (Boolean)


5937
5938
5939
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5937

def enable_speaker_diarization
  @enable_speaker_diarization
end

#enable_word_confidenceBoolean Also known as: enable_word_confidence?

Optional. If true, the top result includes a list of words and the confidence for those words. If false, no word-level confidence information is returned. The default is false. Corresponds to the JSON property enableWordConfidence

Returns:

  • (Boolean)


5945
5946
5947
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5945

def enable_word_confidence
  @enable_word_confidence
end

#filter_profanityBoolean Also known as: filter_profanity?

Optional. If set to true, the server will attempt to filter out profanities, replacing all but the initial character in each filtered word with asterisks, e.g. "f***". If set to false or omitted, profanities won't be filtered out. Corresponds to the JSON property filterProfanity

Returns:

  • (Boolean)


5953
5954
5955
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5953

def filter_profanity
  @filter_profanity
end

#language_codeString

Required. Required The language of the supplied audio as a BCP-47 language tag. Example: "en-US". See Language Support for a list of the currently supported language codes. Corresponds to the JSON property languageCode

Returns:

  • (String)


5962
5963
5964
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5962

def language_code
  @language_code
end

#max_alternativesFixnum

Optional. Maximum number of recognition hypotheses to be returned. Specifically, the maximum number of SpeechRecognitionAlternative messages within each SpeechTranscription. The server may return fewer than max_alternatives. Valid values are 0-30. A value of 0 or 1 will return a maximum of one. If omitted, will return a maximum of one. Corresponds to the JSON property maxAlternatives

Returns:

  • (Fixnum)


5971
5972
5973
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5971

def max_alternatives
  @max_alternatives
end

#speech_contextsArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1SpeechContext>

Optional. A means to provide context to assist the speech recognition. Corresponds to the JSON property speechContexts



5976
5977
5978
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5976

def speech_contexts
  @speech_contexts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 5983

def update!(**args)
  @audio_output_uri_prefix = args[:audio_output_uri_prefix] if args.key?(:audio_output_uri_prefix)
  @audio_tracks = args[:audio_tracks] if args.key?(:audio_tracks)
  @diarization_speaker_count = args[:diarization_speaker_count] if args.key?(:diarization_speaker_count)
  @enable_automatic_punctuation = args[:enable_automatic_punctuation] if args.key?(:enable_automatic_punctuation)
  @enable_speaker_diarization = args[:enable_speaker_diarization] if args.key?(:enable_speaker_diarization)
  @enable_word_confidence = args[:enable_word_confidence] if args.key?(:enable_word_confidence)
  @filter_profanity = args[:filter_profanity] if args.key?(:filter_profanity)
  @language_code = args[:language_code] if args.key?(:language_code)
  @max_alternatives = args[:max_alternatives] if args.key?(:max_alternatives)
  @speech_contexts = args[:speech_contexts] if args.key?(:speech_contexts)
end