Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb
Overview
Annotation progress for a single video.
Instance Attribute Summary collapse
-
#export_status ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ExportToOutputUriStatus
Status of exporting annotation response to user specified
output_uri. -
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one feature.
-
#input_uri ⇒ String
Video file location in Cloud Storage.
-
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far.
-
#segment ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoSegment
Video segment.
-
#start_time ⇒ String
Time when the request was received.
-
#update_time ⇒ String
Time of the most recent update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress
constructor
A new instance of GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress
Returns a new instance of GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress.
6331 6332 6333 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_status ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ExportToOutputUriStatus
Status of exporting annotation response to user specified output_uri.
Corresponds to the JSON property exportStatus
6297 6298 6299 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6297 def export_status @export_status end |
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one
feature.
Corresponds to the JSON property feature
6303 6304 6305 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6303 def feature @feature end |
#input_uri ⇒ String
Video file location in Cloud Storage.
Corresponds to the JSON property inputUri
6308 6309 6310 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6308 def input_uri @input_uri end |
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far. Guaranteed to be 100 when fully
processed.
Corresponds to the JSON property progressPercent
6314 6315 6316 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6314 def progress_percent @progress_percent end |
#segment ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoSegment
Video segment.
Corresponds to the JSON property segment
6319 6320 6321 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6319 def segment @segment end |
#start_time ⇒ String
Time when the request was received.
Corresponds to the JSON property startTime
6324 6325 6326 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6324 def start_time @start_time end |
#update_time ⇒ String
Time of the most recent update.
Corresponds to the JSON property updateTime
6329 6330 6331 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6329 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6336 6337 6338 6339 6340 6341 6342 6343 6344 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6336 def update!(**args) @export_status = args[:export_status] if args.key?(:export_status) @feature = args[:feature] if args.key?(:feature) @input_uri = args[:input_uri] if args.key?(:input_uri) @progress_percent = args[:progress_percent] if args.key?(:progress_percent) @segment = args[:segment] if args.key?(:segment) @start_time = args[:start_time] if args.key?(:start_time) @update_time = args[:update_time] if args.key?(:update_time) end |