Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb

Overview

Video context and/or feature-specific parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1VideoContext

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1VideoContext.



6539
6540
6541
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explicit_content_detection_configGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ExplicitContentDetectionConfig

Config for EXPLICIT_CONTENT_DETECTION. Corresponds to the JSON property explicitContentDetectionConfig



6495
6496
6497
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6495

def explicit_content_detection_config
  @explicit_content_detection_config
end

#face_detection_configGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1FaceDetectionConfig

Config for FACE_DETECTION. Corresponds to the JSON property faceDetectionConfig



6500
6501
6502
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6500

def face_detection_config
  @face_detection_config
end

#label_detection_configGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelDetectionConfig

Config for LABEL_DETECTION. Corresponds to the JSON property labelDetectionConfig



6505
6506
6507
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6505

def label_detection_config
  @label_detection_config
end

#object_tracking_configGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ObjectTrackingConfig

Config for OBJECT_TRACKING. Corresponds to the JSON property objectTrackingConfig



6510
6511
6512
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6510

def object_tracking_config
  @object_tracking_config
end

#person_detection_configGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1PersonDetectionConfig

Config for PERSON_DETECTION. Corresponds to the JSON property personDetectionConfig



6515
6516
6517
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6515

def person_detection_config
  @person_detection_config
end

#segmentsArray<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoSegment>

Video segments to annotate. The segments may overlap and are not required to be contiguous or span the whole video. If unspecified, each video is treated as a single segment. Corresponds to the JSON property segments



6522
6523
6524
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6522

def segments
  @segments
end

#shot_change_detection_configGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ShotChangeDetectionConfig

Config for SHOT_CHANGE_DETECTION. Corresponds to the JSON property shotChangeDetectionConfig



6527
6528
6529
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6527

def shot_change_detection_config
  @shot_change_detection_config
end

#speech_transcription_configGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1SpeechTranscriptionConfig

Config for SPEECH_TRANSCRIPTION. Corresponds to the JSON property speechTranscriptionConfig



6532
6533
6534
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6532

def speech_transcription_config
  @speech_transcription_config
end

#text_detection_configGoogle::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1TextDetectionConfig

Config for TEXT_DETECTION. Corresponds to the JSON property textDetectionConfig



6537
6538
6539
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6537

def text_detection_config
  @text_detection_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6544

def update!(**args)
  @explicit_content_detection_config = args[:explicit_content_detection_config] if args.key?(:explicit_content_detection_config)
  @face_detection_config = args[:face_detection_config] if args.key?(:face_detection_config)
  @label_detection_config = args[:label_detection_config] if args.key?(:label_detection_config)
  @object_tracking_config = args[:object_tracking_config] if args.key?(:object_tracking_config)
  @person_detection_config = args[:person_detection_config] if args.key?(:person_detection_config)
  @segments = args[:segments] if args.key?(:segments)
  @shot_change_detection_config = args[:shot_change_detection_config] if args.key?(:shot_change_detection_config)
  @speech_transcription_config = args[:speech_transcription_config] if args.key?(:speech_transcription_config)
  @text_detection_config = args[:text_detection_config] if args.key?(:text_detection_config)
end