Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb
Overview
Annotation results for a single video.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#explicit_annotation ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation
Explicit content annotation (based on per-frame visual signals only).
-
#face_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1FaceAnnotation>
Deprecated.
-
#face_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1FaceDetectionAnnotation>
Face detection annotations.
-
#frame_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Label annotations on frame level.
-
#input_uri ⇒ String
Video file location in Cloud Storage.
-
#logo_recognition_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LogoRecognitionAnnotation>
Annotations for list of logos detected, tracked and recognized in video.
-
#object_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation>
Annotations for list of objects detected and tracked in video.
-
#person_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1PersonDetectionAnnotation>
Person detection annotations.
-
#segment ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
-
#segment_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Topical label annotations on video level or user-specified segment level.
-
#segment_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Presence label annotations on video level or user-specified segment level.
-
#shot_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment>
Shot annotations.
-
#shot_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Topical label annotations on shot level.
-
#shot_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Presence label annotations on shot level.
-
#speech_transcriptions ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1SpeechTranscription>
Speech transcription.
-
#text_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1TextAnnotation>
OCR text detection and tracking.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults
constructor
A new instance of GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults
Returns a new instance of GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults.
4657 4658 4659 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4560 4561 4562 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4560 def error @error end |
#explicit_annotation ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation
Explicit content annotation (based on per-frame visual signals only). If no
explicit content has been detected in a frame, no annotations are present for
that frame.
Corresponds to the JSON property explicitAnnotation
4567 4568 4569 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4567 def explicit_annotation @explicit_annotation end |
#face_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1FaceAnnotation>
Deprecated. Please use face_detection_annotations instead.
Corresponds to the JSON property faceAnnotations
4572 4573 4574 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4572 def face_annotations @face_annotations end |
#face_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1FaceDetectionAnnotation>
Face detection annotations.
Corresponds to the JSON property faceDetectionAnnotations
4577 4578 4579 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4577 def face_detection_annotations @face_detection_annotations end |
#frame_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Label annotations on frame level. There is exactly one element for each unique
label.
Corresponds to the JSON property frameLabelAnnotations
4583 4584 4585 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4583 def frame_label_annotations @frame_label_annotations end |
#input_uri ⇒ String
Video file location in Cloud Storage.
Corresponds to the JSON property inputUri
4588 4589 4590 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4588 def input_uri @input_uri end |
#logo_recognition_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LogoRecognitionAnnotation>
Annotations for list of logos detected, tracked and recognized in video.
Corresponds to the JSON property logoRecognitionAnnotations
4593 4594 4595 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4593 def logo_recognition_annotations @logo_recognition_annotations end |
#object_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation>
Annotations for list of objects detected and tracked in video.
Corresponds to the JSON property objectAnnotations
4598 4599 4600 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4598 def object_annotations @object_annotations end |
#person_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1PersonDetectionAnnotation>
Person detection annotations.
Corresponds to the JSON property personDetectionAnnotations
4603 4604 4605 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4603 def person_detection_annotations @person_detection_annotations end |
#segment ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
Corresponds to the JSON property segment
4608 4609 4610 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4608 def segment @segment end |
#segment_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Topical label annotations on video level or user-specified segment level.
There is exactly one element for each unique label.
Corresponds to the JSON property segmentLabelAnnotations
4614 4615 4616 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4614 def segment_label_annotations @segment_label_annotations end |
#segment_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Presence label annotations on video level or user-specified segment level.
There is exactly one element for each unique label. Compared to the existing
topical segment_label_annotations, this field presents more fine-grained,
segment-level labels detected in video content and is made available only when
the client sets LabelDetectionConfig.model to "builtin/latest" in the
request.
Corresponds to the JSON property segmentPresenceLabelAnnotations
4624 4625 4626 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4624 def segment_presence_label_annotations @segment_presence_label_annotations end |
#shot_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment>
Shot annotations. Each shot is represented as a video segment.
Corresponds to the JSON property shotAnnotations
4629 4630 4631 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4629 def shot_annotations @shot_annotations end |
#shot_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Topical label annotations on shot level. There is exactly one element for each
unique label.
Corresponds to the JSON property shotLabelAnnotations
4635 4636 4637 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4635 def shot_label_annotations @shot_label_annotations end |
#shot_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>
Presence label annotations on shot level. There is exactly one element for
each unique label. Compared to the existing topical shot_label_annotations,
this field presents more fine-grained, shot-level labels detected in video
content and is made available only when the client sets LabelDetectionConfig.
model to "builtin/latest" in the request.
Corresponds to the JSON property shotPresenceLabelAnnotations
4644 4645 4646 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4644 def shot_presence_label_annotations @shot_presence_label_annotations end |
#speech_transcriptions ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1SpeechTranscription>
Speech transcription.
Corresponds to the JSON property speechTranscriptions
4649 4650 4651 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4649 def speech_transcriptions @speech_transcriptions end |
#text_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p2beta1TextAnnotation>
OCR text detection and tracking. Annotations for list of detected text
snippets. Each will have list of frame information associated with it.
Corresponds to the JSON property textAnnotations
4655 4656 4657 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4655 def text_annotations @text_annotations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 4677 4678 4679 4680 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 4662 def update!(**args) @error = args[:error] if args.key?(:error) @explicit_annotation = args[:explicit_annotation] if args.key?(:explicit_annotation) @face_annotations = args[:face_annotations] if args.key?(:face_annotations) @face_detection_annotations = args[:face_detection_annotations] if args.key?(:face_detection_annotations) @frame_label_annotations = args[:frame_label_annotations] if args.key?(:frame_label_annotations) @input_uri = args[:input_uri] if args.key?(:input_uri) @logo_recognition_annotations = args[:logo_recognition_annotations] if args.key?(:logo_recognition_annotations) @object_annotations = args[:object_annotations] if args.key?(:object_annotations) @person_detection_annotations = args[:person_detection_annotations] if args.key?(:person_detection_annotations) @segment = args[:segment] if args.key?(:segment) @segment_label_annotations = args[:segment_label_annotations] if args.key?(:segment_label_annotations) @segment_presence_label_annotations = args[:segment_presence_label_annotations] if args.key?(:segment_presence_label_annotations) @shot_annotations = args[:shot_annotations] if args.key?(:shot_annotations) @shot_label_annotations = args[:shot_label_annotations] if args.key?(:shot_label_annotations) @shot_presence_label_annotations = args[:shot_presence_label_annotations] if args.key?(:shot_presence_label_annotations) @speech_transcriptions = args[:speech_transcriptions] if args.key?(:speech_transcriptions) @text_annotations = args[:text_annotations] if args.key?(:text_annotations) end |