Class: Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoAnnotationResults
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoAnnotationResults
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p3beta1/classes.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb,
lib/google/apis/videointelligence_v1p3beta1/representations.rb
Overview
Annotation results for a single video.
Instance Attribute Summary collapse
-
#celebrity_recognition_annotations ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1CelebrityRecognitionAnnotation
Celebrity recognition annotation per video.
-
#error ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#explicit_annotation ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ExplicitContentAnnotation
Explicit content annotation (based on per-frame visual signals only).
-
#face_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1FaceAnnotation>
Deprecated.
-
#face_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1FaceDetectionAnnotation>
Face detection annotations.
-
#frame_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Label annotations on frame level.
-
#input_uri ⇒ String
Video file location in Cloud Storage.
-
#logo_recognition_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation>
Annotations for list of logos detected, tracked and recognized in video.
-
#object_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ObjectTrackingAnnotation>
Annotations for list of objects detected and tracked in video.
-
#person_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1PersonDetectionAnnotation>
Person detection annotations.
-
#segment ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoSegment
Video segment.
-
#segment_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Topical label annotations on video level or user-specified segment level.
-
#segment_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Presence label annotations on video level or user-specified segment level.
-
#shot_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoSegment>
Shot annotations.
-
#shot_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Topical label annotations on shot level.
-
#shot_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Presence label annotations on shot level.
-
#speech_transcriptions ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1SpeechTranscription>
Speech transcription.
-
#text_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1TextAnnotation>
OCR text detection and tracking.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1VideoAnnotationResults
constructor
A new instance of GoogleCloudVideointelligenceV1p3beta1VideoAnnotationResults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1VideoAnnotationResults
Returns a new instance of GoogleCloudVideointelligenceV1p3beta1VideoAnnotationResults.
6461 6462 6463 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#celebrity_recognition_annotations ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1CelebrityRecognitionAnnotation
Celebrity recognition annotation per video.
Corresponds to the JSON property celebrityRecognitionAnnotations
6354 6355 6356 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6354 def celebrity_recognition_annotations @celebrity_recognition_annotations end |
#error ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
6364 6365 6366 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6364 def error @error end |
#explicit_annotation ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ExplicitContentAnnotation
Explicit content annotation (based on per-frame visual signals only). If no
explicit content has been detected in a frame, no annotations are present for
that frame.
Corresponds to the JSON property explicitAnnotation
6371 6372 6373 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6371 def explicit_annotation @explicit_annotation end |
#face_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1FaceAnnotation>
Deprecated. Please use face_detection_annotations instead.
Corresponds to the JSON property faceAnnotations
6376 6377 6378 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6376 def face_annotations @face_annotations end |
#face_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1FaceDetectionAnnotation>
Face detection annotations.
Corresponds to the JSON property faceDetectionAnnotations
6381 6382 6383 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6381 def face_detection_annotations @face_detection_annotations end |
#frame_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Label annotations on frame level. There is exactly one element for each unique
label.
Corresponds to the JSON property frameLabelAnnotations
6387 6388 6389 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6387 def frame_label_annotations @frame_label_annotations end |
#input_uri ⇒ String
Video file location in Cloud Storage.
Corresponds to the JSON property inputUri
6392 6393 6394 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6392 def input_uri @input_uri end |
#logo_recognition_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation>
Annotations for list of logos detected, tracked and recognized in video.
Corresponds to the JSON property logoRecognitionAnnotations
6397 6398 6399 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6397 def logo_recognition_annotations @logo_recognition_annotations end |
#object_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1ObjectTrackingAnnotation>
Annotations for list of objects detected and tracked in video.
Corresponds to the JSON property objectAnnotations
6402 6403 6404 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6402 def object_annotations @object_annotations end |
#person_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1PersonDetectionAnnotation>
Person detection annotations.
Corresponds to the JSON property personDetectionAnnotations
6407 6408 6409 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6407 def person_detection_annotations @person_detection_annotations end |
#segment ⇒ Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoSegment
Video segment.
Corresponds to the JSON property segment
6412 6413 6414 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6412 def segment @segment end |
#segment_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Topical label annotations on video level or user-specified segment level.
There is exactly one element for each unique label.
Corresponds to the JSON property segmentLabelAnnotations
6418 6419 6420 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6418 def segment_label_annotations @segment_label_annotations end |
#segment_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Presence label annotations on video level or user-specified segment level.
There is exactly one element for each unique label. Compared to the existing
topical segment_label_annotations, this field presents more fine-grained,
segment-level labels detected in video content and is made available only when
the client sets LabelDetectionConfig.model to "builtin/latest" in the
request.
Corresponds to the JSON property segmentPresenceLabelAnnotations
6428 6429 6430 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6428 def segment_presence_label_annotations @segment_presence_label_annotations end |
#shot_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1VideoSegment>
Shot annotations. Each shot is represented as a video segment.
Corresponds to the JSON property shotAnnotations
6433 6434 6435 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6433 def shot_annotations @shot_annotations end |
#shot_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Topical label annotations on shot level. There is exactly one element for each
unique label.
Corresponds to the JSON property shotLabelAnnotations
6439 6440 6441 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6439 def shot_label_annotations @shot_label_annotations end |
#shot_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>
Presence label annotations on shot level. There is exactly one element for
each unique label. Compared to the existing topical shot_label_annotations,
this field presents more fine-grained, shot-level labels detected in video
content and is made available only when the client sets LabelDetectionConfig.
model to "builtin/latest" in the request.
Corresponds to the JSON property shotPresenceLabelAnnotations
6448 6449 6450 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6448 def shot_presence_label_annotations @shot_presence_label_annotations end |
#speech_transcriptions ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1SpeechTranscription>
Speech transcription.
Corresponds to the JSON property speechTranscriptions
6453 6454 6455 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6453 def speech_transcriptions @speech_transcriptions end |
#text_annotations ⇒ Array<Google::Apis::VideointelligenceV1p3beta1::GoogleCloudVideointelligenceV1p3beta1TextAnnotation>
OCR text detection and tracking. Annotations for list of detected text
snippets. Each will have list of frame information associated with it.
Corresponds to the JSON property textAnnotations
6459 6460 6461 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6459 def text_annotations @text_annotations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 6478 6479 6480 6481 6482 6483 6484 6485 |
# File 'lib/google/apis/videointelligence_v1p3beta1/classes.rb', line 6466 def update!(**args) @celebrity_recognition_annotations = args[:celebrity_recognition_annotations] if args.key?(:celebrity_recognition_annotations) @error = args[:error] if args.key?(:error) @explicit_annotation = args[:explicit_annotation] if args.key?(:explicit_annotation) @face_annotations = args[:face_annotations] if args.key?(:face_annotations) @face_detection_annotations = args[:face_detection_annotations] if args.key?(:face_detection_annotations) @frame_label_annotations = args[:frame_label_annotations] if args.key?(:frame_label_annotations) @input_uri = args[:input_uri] if args.key?(:input_uri) @logo_recognition_annotations = args[:logo_recognition_annotations] if args.key?(:logo_recognition_annotations) @object_annotations = args[:object_annotations] if args.key?(:object_annotations) @person_detection_annotations = args[:person_detection_annotations] if args.key?(:person_detection_annotations) @segment = args[:segment] if args.key?(:segment) @segment_label_annotations = args[:segment_label_annotations] if args.key?(:segment_label_annotations) @segment_presence_label_annotations = args[:segment_presence_label_annotations] if args.key?(:segment_presence_label_annotations) @shot_annotations = args[:shot_annotations] if args.key?(:shot_annotations) @shot_label_annotations = args[:shot_label_annotations] if args.key?(:shot_label_annotations) @shot_presence_label_annotations = args[:shot_presence_label_annotations] if args.key?(:shot_presence_label_annotations) @speech_transcriptions = args[:speech_transcriptions] if args.key?(:speech_transcriptions) @text_annotations = args[:text_annotations] if args.key?(:text_annotations) end |